
import oscP5.*;

int S = 200;

OscP5 osc;

float kickState;
float snareState;
float bassState;
float leadState;

int bassPitch;
int leadPitch;

void setup() {
  size(2*S,2*S);
  frameRate(30);
  smooth();
  osc = new OscP5(this,7006);
  osc.plug(this,"kick","/kick");
  osc.plug(this,"snare","/snare");
  osc.plug(this,"bass","/bass");
  osc.plug(this,"lead","/lead");
}

void draw() {
  render();
  update();
}

void kolor(int r, int g, int b) {
  stroke(r,g,b,255);
  fill(r,g,b,64);
}

boolean alive(float state) {
  return state > 0.1;
}

void render() {
  strokeWeight(0);
  fill(0,0,0,255);
  rect(0,0,2*S,2*S);
  
  strokeWeight(S/50);
  
  if(alive(kickState)) {
    kolor(128,64,64);
    ellipse(S,S,kickState*S*2,kickState*S*2);
  }
  
  if(alive(snareState)) {
    kolor(128,128,255);
    ellipse(S,S,snareState*S*2,snareState*S/4);
  }
  
  if(alive(bassState)) {
    float bassShift = 2*(bassPitch%12)*S/12;
    kolor(255,255,255);
    rect(S-bassShift/2,2*S-bassState*S/2,S/2,2*S);
  }
  
  if(alive(leadState)) {
    float leadShift = 2*(leadPitch%12)*S/12;
    kolor(0,255,0);
    rect(leadShift-leadState*S/8,-S,leadState*S/4,3*S);
  }
}

void update() {
  float k = 0.75;
  kickState  *= k;
  snareState *= k;
  bassState  *= k;
  leadState  *= k;
}

void kick() {
  kickState = 1;
}

void snare() {
  snareState = 1;
}

void bass(float pitch) {
  bassState = 1;
  bassPitch = (int)pitch; 
}

void lead(float pitch) {
  leadState = 1;
  leadPitch = (int)pitch; 
}
